==> rdc_flutter_sdk-0.0.1.tar.gz: lib/src/repositories/event_repo.dart <==
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:rdc_flutter_sdk/src/model/hive/rabbit_request_hive.dart';
import 'package:rdc_flutter_sdk/src/model/rabbit_request.dart';
import 'package:rdc_flutter_sdk/src/model/realm/rabbit_request_realm.dart';
import 'package:rdc_flutter_sdk/src/repositories/base_repo.dart';

class EventRepo
    extends BaseRepo<RabbitRequest, RabbitRequestHive, RabbitRequestRealm> {
  EventRepo() : super(RabbitRequest.boxName);

  Future<List<RabbitRequest>> getRequests() async {
    var results = await getAll();
    if (results.isEmpty) return [];
    return results.where((e) => !e.isSend).toList();
  }

  Future<void> updateSend(List<int> ids) async {
    if (super.config.rabbitDataConfig.dbType == DBType.realm) {
      for (var id in ids) {
        var realm = super.realmDB.db;
        var data = realm.find<RabbitRequestRealm>(id);
        if (data == null) return;
        realm.write(() {
          data.isSend = true;
        });
      }

      return;
    }

    var results = await getAll();
    if (results.isEmpty) return;
    var data = results.where((e) => ids.contains(e.id));
    if (data.isEmpty) return;
    for (var e in data) {
      e.isSend = true;
      await update(e.id, e);
    }
  }

  Future<void> deleteAllSent() async {
    var results = await getAll();
    if (results.isEmpty) return;
    var data = results.where((e) => e.isSend).map((e) => e.id);
    if (data.isEmpty) return;
    await deleteAllKeys(data.toList());
  }
}

==> rdc_flutter_sdk-0.0.3.tar.gz: lib/src/repositories/event_repo.dart <==
import 'package:intl/intl.dart';
import 'package:rdc_flutter_sdk/rabbit_data.dart';
import 'package:rdc_flutter_sdk/src/constants/app_constants.dart';
import 'package:rdc_flutter_sdk/src/model/hive/rabbit_request_hive.dart';
import 'package:rdc_flutter_sdk/src/model/realm/rabbit_request_realm.dart';
import 'package:rdc_flutter_sdk/src/repositories/base_repo.dart';

class EventRepo
    extends BaseRepo<RabbitRequest, RabbitRequestHive, RabbitRequestRealm> {
  Future<EventRepo> init() async {
    await super.initBase(RabbitRequest.boxName);
    return this;
  }

  Future<List<RabbitRequest>> getRequests() async {
    var results = await getAll();
    if (results.isEmpty) return [];
    return results.where((e) => !e.isSend).toList();
  }

  Future<void> updateSend(List<int> ids, {bool isSend = true}) async {
    if (super.config.dbType == DBType.realm.name) {
      for (var id in ids) {
        var realm = super.realmDB.db;
        var data = realm.find<RabbitRequestRealm>(id);
        if (data == null) return;
        realm.write(() {
          data.isSend = isSend;
        });
      }

      return;
    }

    var results = await getAll();
    if (results.isEmpty) return;
    var data = results.where((e) => ids.contains(e.id));
    if (data.isEmpty) return;
    for (var e in data) {
      e.isSend = true;
      await update(e.id, e);
    }
  }

  Future<void> deleteAllSent() async {
    var results = await getAll();
    if (results.isEmpty) return;
    var data = results.where((e) => e.isSend).map((e) => e.id);
    if (data.isEmpty) return;
    await deleteAllKeys(data.toList());
  }

  Future<void> deleteAfterRetentionDays(int days) async {
    var results = await getAll();
    results = results.where((e) => e.isSend).toList();

    if (results.isEmpty) return;

    var format = DateFormat(dateFormat);
    var now = DateTime.now();
    var data = results
        .where(
            (e) => (now.difference(format.parse(e.time)).inDays).abs() > days)
        .map((e) => e.id);
    if (data.isEmpty) return;
    await deleteAllKeys(data.toList());
  }
}
